tlslite.utils.cryptomath

Package tlslite :: Package utils :: Module cryptomath |
[show private | hide private]
[frames | no frames]

## Module tlslite.utils.cryptomath

cryptomath module

This module has basic math/crypto code.

Function Summary
| `base64ToBytes(s)`
| `base64ToNumber(s)`
| `base64ToString(s)`
| `bytesToBase64(bytes)`
| `bytesToNumber(bytes)`
| `gcd(a, b)`
| `getBase64Nonce(numChars)`
| `getRandomBytes(howMany)`
| `getRandomNumber(low, high)`
| `getRandomPrime(bits, display)`
| `getRandomSafePrime(bits, display)`
| `hashAndBase64(s)`
| `invMod(a, b)`
| `isPrime(n, iterations, display)`
| `lcm(a, b)`
| `makeSieve(n)`
| `mpiToNumber(mpi)`
| `numberToBase64(n)`
| `numberToBytes(n)`
| `numberToMPI(n)`
| `numberToString(s)`
| `numBytes(n)`
| `powMod(base, power, modulus)`
| `stringToBase64(s)`
| `stringToNumber(s)`

Variable Summary
`list` | `sieve` = `[2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41,...`

Variable Details

    ### sieve Type: `list` Value:
        [2, 3, 5, 7, 11, 13, 17, 19, 23]

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net